@@ -9,12 +9,12 @@ must be installed to read HTML tables.
 """
 
 import warnings
+from copy import deepcopy
 
-from . import core
 from astropy.table import Column
 from astropy.utils.xml import writer
 
-from copy import deepcopy
+from . import core
 
 
 class SoupString(str):
@@ -46,16 +46,15 @@ def identify_table(soup, htmldict, numtable):
     Checks whether the given BeautifulSoup tag is the table
     the user intends to process.
     """
-
-    if soup is None or soup.name != 'table':
+    if soup is None or soup.name != "table":
         return False  # Tag is not a <table>
 
-    elif 'table_id' not in htmldict:
+    elif "table_id" not in htmldict:
         return numtable == 1
-    table_id = htmldict['table_id']
+    table_id = htmldict["table_id"]
 
     if isinstance(table_id, str):
-        return 'id' in soup.attrs and soup['id'] == table_id
+        return "id" in soup.attrs and soup["id"] == table_id
     elif isinstance(table_id, int):
         return table_id == numtable
 
@@ -76,35 +75,38 @@ class HTMLInputter(core.BaseInputter):
         Convert the given input into a list of SoupString rows
         for further processing.
         """
-
         try:
             from bs4 import BeautifulSoup
         except ImportError:
-            raise core.OptionalTableImportError('BeautifulSoup must be '
-                                                'installed to read HTML tables')
+            raise core.OptionalTableImportError(
+                "BeautifulSoup must be installed to read HTML tables"
+            )
 
-        if 'parser' not in self.html:
+        if "parser" not in self.html:
             with warnings.catch_warnings():
                 # Ignore bs4 parser warning #4550.
-                warnings.filterwarnings('ignore', '.*no parser was explicitly specified.*')
-                soup = BeautifulSoup('\n'.join(lines))
+                warnings.filterwarnings(
+                    "ignore", ".*no parser was explicitly specified.*"
+                )
+                soup = BeautifulSoup("\n".join(lines))
         else:  # use a custom backend parser
-            soup = BeautifulSoup('\n'.join(lines), self.html['parser'])
-        tables = soup.find_all('table')
+            soup = BeautifulSoup("\n".join(lines), self.html["parser"])
+        tables = soup.find_all("table")
         for i, possible_table in enumerate(tables):
             if identify_table(possible_table, self.html, i + 1):
                 table = possible_table  # Find the correct table
                 break
         else:
-            if isinstance(self.html['table_id'], int):
+            if isinstance(self.html["table_id"], int):
                 err_descr = f"number {self.html['table_id']}"
             else:
                 err_descr = f"id '{self.html['table_id']}'"
             raise core.InconsistentTableError(
-                f'ERROR: HTML table {err_descr} not found')
+                f"ERROR: HTML table {err_descr} not found"
+            )
 
         # Get all table rows
-        soup_list = [SoupString(x) for x in table.find_all('tr')]
+        soup_list = [SoupString(x) for x in table.find_all("tr")]
 
         return soup_list
 
@@ -120,19 +122,24 @@ class HTMLSplitter(core.BaseSplitter):
         """
         for line in lines:
             if not isinstance(line, SoupString):
-                raise TypeError('HTML lines should be of type SoupString')
+                raise TypeError("HTML lines should be of type SoupString")
             soup = line.soup
-            header_elements = soup.find_all('th')
+            header_elements = soup.find_all("th")
             if header_elements:
                 # Return multicolumns as tuples for HTMLHeader handling
-                yield [(el.text.strip(), el['colspan']) if el.has_attr('colspan')
-                       else el.text.strip() for el in header_elements]
-            data_elements = soup.find_all('td')
+                yield [
+                    (el.text.strip(), el["colspan"])
+                    if el.has_attr("colspan")
+                    else el.text.strip()
+                    for el in header_elements
+                ]
+            data_elements = soup.find_all("td")
             if data_elements:
                 yield [el.text.strip() for el in data_elements]
         if len(lines) == 0:
-            raise core.InconsistentTableError('HTML tables must contain data '
-                                              'in a <table> tag')
+            raise core.InconsistentTableError(
+                "HTML tables must contain data in a <table> tag"
+            )
 
 
 class HTMLOutputter(core.TableOutputter):
@@ -144,9 +151,11 @@ class HTMLOutputter(core.TableOutputter):
     of <th>).
     """
 
-    default_converters = [core.convert_numpy(int),
-                          core.convert_numpy(float),
-                          core.convert_numpy(str)]
+    default_converters = [
+        core.convert_numpy(int),
+        core.convert_numpy(float),
+        core.convert_numpy(str),
+    ]
 
     def __call__(self, cols, meta):
         """
@@ -157,9 +166,9 @@ class HTMLOutputter(core.TableOutputter):
 
         while col_num < len(cols):
             col = cols[col_num]
-            if hasattr(col, 'colspan'):
+            if hasattr(col, "colspan"):
                 # Join elements of spanned columns together into list of tuples
-                span_cols = cols[col_num:col_num + col.colspan]
+                span_cols = cols[col_num : col_num + col.colspan]
                 new_col = core.Column(col.name)
                 new_col.str_vals = list(zip(*[x.str_vals for x in span_cols]))
                 new_cols.append(new_col)
@@ -178,10 +187,9 @@ class HTMLHeader(core.BaseHeader):
         """
         Return the line number at which header data begins.
         """
-
         for i, line in enumerate(lines):
             if not isinstance(line, SoupString):
-                raise TypeError('HTML lines should be of type SoupString')
+                raise TypeError("HTML lines should be of type SoupString")
             soup = line.soup
             if soup.th is not None:
                 return i
@@ -203,8 +211,8 @@ class HTMLHeader(core.BaseHeader):
                 new_names.append(name[0])
                 for i in range(1, int(name[1])):
                     # Add dummy columns
-                    self.cols.append(core.Column(''))
-                    new_names.append('')
+                    self.cols.append(core.Column(""))
+                    new_names.append("")
             else:
                 self.cols.append(core.Column(name=name))
                 new_names.append(name)
@@ -219,19 +227,19 @@ class HTMLData(core.BaseData):
         """
         Return the line number at which table data begins.
         """
-
         for i, line in enumerate(lines):
             if not isinstance(line, SoupString):
-                raise TypeError('HTML lines should be of type SoupString')
+                raise TypeError("HTML lines should be of type SoupString")
             soup = line.soup
 
             if soup.td is not None:
                 if soup.th is not None:
-                    raise core.InconsistentTableError('HTML tables cannot '
-                                                      'have headings and data in the same row')
+                    raise core.InconsistentTableError(
+                        "HTML tables cannot have headings and data in the same row"
+                    )
                 return i
 
-        raise core.InconsistentTableError('No start line found for HTML data')
+        raise core.InconsistentTableError("No start line found for HTML data")
 
     def end_line(self, lines):
         """
@@ -241,7 +249,7 @@ class HTMLData(core.BaseData):
 
         for i, line in enumerate(lines):
             if not isinstance(line, SoupString):
-                raise TypeError('HTML lines should be of type SoupString')
+                raise TypeError("HTML lines should be of type SoupString")
             soup = line.soup
             if soup.td is not None:
                 last_index = i
@@ -308,10 +316,10 @@ class HTML(core.BaseReader):
 
     """
 
-    _format_name = 'html'
-    _io_registry_format_aliases = ['html']
-    _io_registry_suffix = '.html'
-    _description = 'HTML table'
+    _format_name = "html"
+    _io_registry_format_aliases = ["html"]
+    _io_registry_suffix = ".html"
+    _description = "HTML table"
 
     header_class = HTMLHeader
     data_class = HTMLData
@@ -325,17 +333,16 @@ class HTML(core.BaseReader):
         """
         super().__init__()
         self.html = deepcopy(htmldict)
-        if 'multicol' not in htmldict:
-            self.html['multicol'] = True
-        if 'table_id' not in htmldict:
-            self.html['table_id'] = 1
+        if "multicol" not in htmldict:
+            self.html["multicol"] = True
+        if "table_id" not in htmldict:
+            self.html["table_id"] = 1
         self.inputter.html = self.html
 
     def read(self, table):
         """
         Read the ``table`` in HTML format and return a resulting ``Table``.
         """
-
         self.outputter = HTMLOutputter()
         return super().read(table)
 
@@ -360,59 +367,67 @@ class HTML(core.BaseReader):
         lines = []
 
         # Set HTML escaping to False for any column in the raw_html_cols input
-        raw_html_cols = self.html.get('raw_html_cols', [])
+        raw_html_cols = self.html.get("raw_html_cols", [])
         if isinstance(raw_html_cols, str):
             raw_html_cols = [raw_html_cols]  # Allow for a single string as input
         cols_escaped = [col.info.name not in raw_html_cols for col in cols]
 
         # Kwargs that get passed on to bleach.clean() if that is available.
-        raw_html_clean_kwargs = self.html.get('raw_html_clean_kwargs', {})
+        raw_html_clean_kwargs = self.html.get("raw_html_clean_kwargs", {})
 
         # Use XMLWriter to output HTML to lines
         w = writer.XMLWriter(ListWriter(lines))
 
-        with w.tag('html'):
-            with w.tag('head'):
+        with w.tag("html"):
+            with w.tag("head"):
                 # Declare encoding and set CSS style for table
-                with w.tag('meta', attrib={'charset': 'utf-8'}):
+                with w.tag("meta", attrib={"charset": "utf-8"}):
                     pass
-                with w.tag('meta', attrib={'http-equiv': 'Content-type',
-                                           'content': 'text/html;charset=UTF-8'}):
+                with w.tag(
+                    "meta",
+                    attrib={
+                        "http-equiv": "Content-type",
+                        "content": "text/html;charset=UTF-8",
+                    },
+                ):
                     pass
-                if 'css' in self.html:
-                    with w.tag('style'):
-                        w.data(self.html['css'])
-                if 'cssfiles' in self.html:
-                    for filename in self.html['cssfiles']:
-                        with w.tag('link', rel="stylesheet", href=filename, type='text/css'):
+                if "css" in self.html:
+                    with w.tag("style"):
+                        w.data(self.html["css"])
+                if "cssfiles" in self.html:
+                    for filename in self.html["cssfiles"]:
+                        with w.tag(
+                            "link", rel="stylesheet", href=filename, type="text/css"
+                        ):
                             pass
-                if 'jsfiles' in self.html:
-                    for filename in self.html['jsfiles']:
-                        with w.tag('script', src=filename):
-                            w.data('')  # need this instead of pass to get <script></script>
-            with w.tag('body'):
-                if 'js' in self.html:
-                    with w.xml_cleaning_method('none'):
-                        with w.tag('script'):
-                            w.data(self.html['js'])
-                if isinstance(self.html['table_id'], str):
-                    html_table_id = self.html['table_id']
+                if "jsfiles" in self.html:
+                    for filename in self.html["jsfiles"]:
+                        with w.tag("script", src=filename):
+                            # need this instead of pass to get <script></script>
+                            w.data("")
+            with w.tag("body"):
+                if "js" in self.html:
+                    with w.xml_cleaning_method("none"):
+                        with w.tag("script"):
+                            w.data(self.html["js"])
+                if isinstance(self.html["table_id"], str):
+                    html_table_id = self.html["table_id"]
                 else:
                     html_table_id = None
-                if 'table_class' in self.html:
-                    html_table_class = self.html['table_class']
+                if "table_class" in self.html:
+                    html_table_class = self.html["table_class"]
                     attrib = {"class": html_table_class}
                 else:
                     attrib = {}
-                with w.tag('table', id=html_table_id, attrib=attrib):
-                    with w.tag('thead'):
-                        with w.tag('tr'):
+                with w.tag("table", id=html_table_id, attrib=attrib):
+                    with w.tag("thead"):
+                        with w.tag("tr"):
                             for col in cols:
-                                if len(col.shape) > 1 and self.html['multicol']:
+                                if len(col.shape) > 1 and self.html["multicol"]:
                                     # Set colspan attribute for multicolumns
-                                    w.start('th', colspan=col.shape[1])
+                                    w.start("th", colspan=col.shape[1])
                                 else:
-                                    w.start('th')
+                                    w.start("th")
                                 w.data(col.info.name.strip())
                                 w.end(indent=False)
                         col_str_iters = []
@@ -426,44 +441,48 @@ class HTML(core.BaseReader):
                         new_cols = []
 
                         for col, col_escaped in zip(cols, cols_escaped):
-                            if len(col.shape) > 1 and self.html['multicol']:
+                            if len(col.shape) > 1 and self.html["multicol"]:
                                 span = col.shape[1]
                                 for i in range(span):
                                     # Split up multicolumns into separate columns
                                     new_col = Column([el[i] for el in col])
 
                                     new_col_iter_str_vals = self.fill_values(
-                                        col, new_col.info.iter_str_vals())
+                                        col, new_col.info.iter_str_vals()
+                                    )
                                     col_str_iters.append(new_col_iter_str_vals)
                                     new_cols_escaped.append(col_escaped)
                                     new_cols.append(new_col)
                             else:
-
-                                col_iter_str_vals = self.fill_values(col, col.info.iter_str_vals())
+                                col_iter_str_vals = self.fill_values(
+                                    col, col.info.iter_str_vals()
+                                )
                                 col_str_iters.append(col_iter_str_vals)
 
                                 new_cols_escaped.append(col_escaped)
 
                     for row in zip(*col_str_iters):
-                        with w.tag('tr'):
+                        with w.tag("tr"):
                             for el, col_escaped in zip(row, new_cols_escaped):
                                 # Potentially disable HTML escaping for column
-                                method = ('escape_xml' if col_escaped else 'bleach_clean')
-                                with w.xml_cleaning_method(method, **raw_html_clean_kwargs):
-                                    w.start('td')
+                                method = "escape_xml" if col_escaped else "bleach_clean"
+                                with w.xml_cleaning_method(
+                                    method, **raw_html_clean_kwargs
+                                ):
+                                    w.start("td")
                                     w.data(el.strip())
                                     w.end(indent=False)
 
         # Fixes XMLWriter's insertion of unwanted line breaks
-        return [''.join(lines)]
+        return ["".join(lines)]
 
     def fill_values(self, col, col_str_iters):
         """
-        Return an iterator of the values with replacements based on fill_values
+        Return an iterator of the values with replacements based on fill_values.
         """
         # check if the col is a masked column and has fill values
-        is_masked_column = hasattr(col, 'mask')
-        has_fill_values = hasattr(col, 'fill_values')
+        is_masked_column = hasattr(col, "mask")
+        has_fill_values = hasattr(col, "fill_values")
 
         for idx, col_str in enumerate(col_str_iters):
             if is_masked_column and has_fill_values:
