@@ -306,7 +306,7 @@ class _BaseHDU:
 
         Parameters
         ----------
-        data : str, bytearray, memoryview, ndarray
+        data : str, bytes, memoryview, ndarray
             A byte string containing the HDU's header and data.
 
         checksum : bool, optional
@@ -382,7 +382,7 @@ class _BaseHDU:
             Output verification option.  Must be one of ``"fix"``,
             ``"silentfix"``, ``"ignore"``, ``"warn"``, or
             ``"exception"``.  May also be any combination of ``"fix"`` or
-            ``"silentfix"`` with ``"+ignore"``, ``+warn``, or ``+exception"
+            ``"silentfix"`` with ``"+ignore"``, ``"+warn"``, or ``"+exception"``
             (e.g. ``"fix+warn"``).  See :ref:`astropy:verify` for more info.
 
         overwrite : bool, optional
